@@ -45,6 +45,7 @@ typedef enum
   WNCK_WINDOW_STATE_FULLSCREEN             = 1 << 8,
   WNCK_WINDOW_STATE_DEMANDS_ATTENTION      = 1 << 9,
   WNCK_WINDOW_STATE_URGENT                 = 1 << 10,
+  WNCK_WINDOW_STATE_ABOVE                  = 1 << 11
 } WnckWindowState;
 
 typedef enum
@@ -65,7 +66,8 @@ typedef enum
   WNCK_WINDOW_ACTION_UNMINIMIZE              = 1 << 13,
   WNCK_WINDOW_ACTION_MAXIMIZE                = 1 << 14,
   WNCK_WINDOW_ACTION_UNMAXIMIZE              = 1 << 15,
-  WNCK_WINDOW_ACTION_FULLSCREEN              = 1 << 16
+  WNCK_WINDOW_ACTION_FULLSCREEN              = 1 << 16,
+  WNCK_WINDOW_ACTION_ABOVE                   = 1 << 17
 } WnckWindowActions;
 
 typedef enum
@@ -81,6 +83,28 @@ typedef enum
   WNCK_WINDOW_SPLASHSCREEN  /* splash screen */
 } WnckWindowType;
 
+typedef enum
+{
+  WNCK_WINDOW_GRAVITY_CURRENT   = 0,
+  WNCK_WINDOW_GRAVITY_NORTHWEST = 1,
+  WNCK_WINDOW_GRAVITY_NORTH     = 2,
+  WNCK_WINDOW_GRAVITY_NORTHEAST = 3,
+  WNCK_WINDOW_GRAVITY_WEST      = 4,
+  WNCK_WINDOW_GRAVITY_CENTER    = 5,
+  WNCK_WINDOW_GRAVITY_EAST      = 6,
+  WNCK_WINDOW_GRAVITY_SOUTHWEST = 7,
+  WNCK_WINDOW_GRAVITY_SOUTH     = 8,
+  WNCK_WINDOW_GRAVITY_SOUTHEAST = 9
+} WnckWindowGravity;
+
+typedef enum
+{
+  WNCK_WINDOW_CHANGE_X      = 1 << 0,
+  WNCK_WINDOW_CHANGE_Y      = 1 << 1,
+  WNCK_WINDOW_CHANGE_WIDTH  = 1 << 2,
+  WNCK_WINDOW_CHANGE_HEIGHT = 1 << 3,
+} WnckWindowMoveResizeMask;
+
 #define WNCK_TYPE_WINDOW              (wnck_window_get_type ())
 #define WNCK_WINDOW(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), WNCK_TYPE_WINDOW, WnckWindow))
 #define WNCK_WINDOW_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), WNCK_TYPE_WINDOW, WnckWindowClass))
@@ -133,10 +157,13 @@ WnckWindow* wnck_window_get (gulong xwindow);
 
 WnckScreen* wnck_window_get_screen    (WnckWindow *window);
 
+gboolean    wnck_window_has_name      (WnckWindow *window);
 const char* wnck_window_get_name      (WnckWindow *window);
+gboolean    wnck_window_has_icon_name (WnckWindow *window);
 const char* wnck_window_get_icon_name (WnckWindow *window);
 
 WnckApplication* wnck_window_get_application  (WnckWindow *window);
+WnckWindow*      wnck_window_get_transient    (WnckWindow *window);
 gulong           wnck_window_get_group_leader (WnckWindow *window);
 gulong           wnck_window_get_xid          (WnckWindow *window);
 
@@ -148,12 +175,15 @@ int         wnck_window_get_pid               (WnckWindow *window);
 gint        wnck_window_get_sort_order        (WnckWindow *window);
 
 WnckWindowType wnck_window_get_window_type    (WnckWindow *window);
+void           wnck_window_set_window_type    (WnckWindow *window,
+                                               WnckWindowType wintype);
 
 gboolean wnck_window_is_minimized              (WnckWindow *window);
 gboolean wnck_window_is_maximized_horizontally (WnckWindow *window);
 gboolean wnck_window_is_maximized_vertically   (WnckWindow *window);
 gboolean wnck_window_is_maximized              (WnckWindow *window);
 gboolean wnck_window_is_shaded                 (WnckWindow *window);
+gboolean wnck_window_is_above                  (WnckWindow *window);
 gboolean wnck_window_is_skip_pager             (WnckWindow *window);
 gboolean wnck_window_is_skip_tasklist          (WnckWindow *window);
 gboolean wnck_window_is_fullscreen             (WnckWindow *window);
@@ -181,6 +211,8 @@ void wnck_window_maximize_vertically     (WnckWindow *window);
 void wnck_window_unmaximize_vertically   (WnckWindow *window);
 void wnck_window_shade                   (WnckWindow *window);
 void wnck_window_unshade                 (WnckWindow *window);
+void wnck_window_make_above              (WnckWindow *window);
+void wnck_window_unmake_above            (WnckWindow *window);
 void wnck_window_stick                   (WnckWindow *window);
 void wnck_window_unstick                 (WnckWindow *window);
 void wnck_window_keyboard_move           (WnckWindow *window);
@@ -201,7 +233,7 @@ gboolean wnck_window_is_active (WnckWindow *window);
 gboolean wnck_window_is_most_recently_activated (WnckWindow *window);
 void     wnck_window_activate_transient (WnckWindow *window,
                                          guint32     timestamp);
-gboolean wnck_window_transient_is_active (WnckWindow *window);
+gboolean wnck_window_transient_is_most_recently_activated (WnckWindow *window);
 
 GdkPixbuf* wnck_window_get_icon      (WnckWindow *window);
 GdkPixbuf* wnck_window_get_mini_icon (WnckWindow *window);
@@ -222,6 +254,13 @@ void wnck_window_get_geometry (WnckWindow *window,
                                int        *yp,
                                int        *widthp,
                                int        *heightp);
+void wnck_window_set_geometry (WnckWindow               *window,
+                               WnckWindowGravity         gravity,
+                               WnckWindowMoveResizeMask  geometry_mask,
+                               int                       x,
+                               int                       y,
+                               int                       width,
+                               int                       height);
 
 gboolean wnck_window_is_visible_on_workspace (WnckWindow    *window,
                                               WnckWorkspace *workspace);
