@@ -19,6 +19,23 @@ wnck_pager_display_mode_get_type (void)
   return etype;
 }
 
+/* enumerations from "screen.h" */
+GType
+wnck_motion_direction_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { WNCK_MOTION_UP, "WNCK_MOTION_UP", "up" },
+      { WNCK_MOTION_DOWN, "WNCK_MOTION_DOWN", "down" },
+      { WNCK_MOTION_LEFT, "WNCK_MOTION_LEFT", "left" },
+      { WNCK_MOTION_RIGHT, "WNCK_MOTION_RIGHT", "right" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("WnckMotionDirection", values);
+  }
+  return etype;
+}
 
 /* enumerations from "tasklist.h" */
 GType
@@ -37,6 +54,21 @@ wnck_tasklist_grouping_type_get_type (void)
   return etype;
 }
 
+/* enumerations from "util.h" */
+GType
+wnck_client_type_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { WNCK_CLIENT_TYPE_APPLICATION, "WNCK_CLIENT_TYPE_APPLICATION", "application" },
+      { WNCK_CLIENT_TYPE_PAGER, "WNCK_CLIENT_TYPE_PAGER", "pager" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("WnckClientType", values);
+  }
+  return etype;
+}
 
 /* enumerations from "window.h" */
 GType
@@ -55,13 +87,14 @@ wnck_window_state_get_type (void)
       { WNCK_WINDOW_STATE_HIDDEN, "WNCK_WINDOW_STATE_HIDDEN", "hidden" },
       { WNCK_WINDOW_STATE_FULLSCREEN, "WNCK_WINDOW_STATE_FULLSCREEN", "fullscreen" },
       { WNCK_WINDOW_STATE_DEMANDS_ATTENTION, "WNCK_WINDOW_STATE_DEMANDS_ATTENTION", "demands-attention" },
+      { WNCK_WINDOW_STATE_URGENT, "WNCK_WINDOW_STATE_URGENT", "urgent" },
+      { WNCK_WINDOW_STATE_ABOVE, "WNCK_WINDOW_STATE_ABOVE", "above" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static ("WnckWindowState", values);
   }
   return etype;
 }
-
 GType
 wnck_window_actions_get_type (void)
 {
@@ -84,13 +117,14 @@ wnck_window_actions_get_type (void)
       { WNCK_WINDOW_ACTION_UNMINIMIZE, "WNCK_WINDOW_ACTION_UNMINIMIZE", "unminimize" },
       { WNCK_WINDOW_ACTION_MAXIMIZE, "WNCK_WINDOW_ACTION_MAXIMIZE", "maximize" },
       { WNCK_WINDOW_ACTION_UNMAXIMIZE, "WNCK_WINDOW_ACTION_UNMAXIMIZE", "unmaximize" },
+      { WNCK_WINDOW_ACTION_FULLSCREEN, "WNCK_WINDOW_ACTION_FULLSCREEN", "fullscreen" },
+      { WNCK_WINDOW_ACTION_ABOVE, "WNCK_WINDOW_ACTION_ABOVE", "above" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static ("WnckWindowActions", values);
   }
   return etype;
 }
-
 GType
 wnck_window_type_get_type (void)
 {
@@ -112,7 +146,44 @@ wnck_window_type_get_type (void)
   }
   return etype;
 }
-
+GType
+wnck_window_gravity_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { WNCK_WINDOW_GRAVITY_CURRENT, "WNCK_WINDOW_GRAVITY_CURRENT", "current" },
+      { WNCK_WINDOW_GRAVITY_NORTHWEST, "WNCK_WINDOW_GRAVITY_NORTHWEST", "northwest" },
+      { WNCK_WINDOW_GRAVITY_NORTH, "WNCK_WINDOW_GRAVITY_NORTH", "north" },
+      { WNCK_WINDOW_GRAVITY_NORTHEAST, "WNCK_WINDOW_GRAVITY_NORTHEAST", "northeast" },
+      { WNCK_WINDOW_GRAVITY_WEST, "WNCK_WINDOW_GRAVITY_WEST", "west" },
+      { WNCK_WINDOW_GRAVITY_CENTER, "WNCK_WINDOW_GRAVITY_CENTER", "center" },
+      { WNCK_WINDOW_GRAVITY_EAST, "WNCK_WINDOW_GRAVITY_EAST", "east" },
+      { WNCK_WINDOW_GRAVITY_SOUTHWEST, "WNCK_WINDOW_GRAVITY_SOUTHWEST", "southwest" },
+      { WNCK_WINDOW_GRAVITY_SOUTH, "WNCK_WINDOW_GRAVITY_SOUTH", "south" },
+      { WNCK_WINDOW_GRAVITY_SOUTHEAST, "WNCK_WINDOW_GRAVITY_SOUTHEAST", "southeast" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("WnckWindowGravity", values);
+  }
+  return etype;
+}
+GType
+wnck_window_move_resize_mask_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GFlagsValue values[] = {
+      { WNCK_WINDOW_CHANGE_X, "WNCK_WINDOW_CHANGE_X", "x" },
+      { WNCK_WINDOW_CHANGE_Y, "WNCK_WINDOW_CHANGE_Y", "y" },
+      { WNCK_WINDOW_CHANGE_WIDTH, "WNCK_WINDOW_CHANGE_WIDTH", "width" },
+      { WNCK_WINDOW_CHANGE_HEIGHT, "WNCK_WINDOW_CHANGE_HEIGHT", "height" },
+      { 0, NULL, NULL }
+    };
+    etype = g_flags_register_static ("WnckWindowMoveResizeMask", values);
+  }
+  return etype;
+}
 
 /* Generated data ends here */
 
